pub struct StreamListener<D> { /* private fields */ }Expand description
An owned listener for stream events.
This is created by stream::ListenerLocalBuilder and will receive events as long as it is alive.
When this gets dropped, the listener gets unregistered and no events will be received by it.
Implementations
Sourceimpl<D> StreamListener<D>
impl<D> StreamListener<D>
Sourcepub fn unregister(self)
pub fn unregister(self)
Stop the listener from receiving any events
Removes the listener registration and cleans up allocated resources.